"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const safeStringify = require("json-stringify-safe");
const util_1 = require("util");
const inspectOptions = {
    depth: Infinity,
    maxArrayLength: Infinity,
    compact: false,
    breakLength: Infinity,
};
function colorize(logOutput) {
    if (logOutput.level === 'ERROR') {
        const inspected = util_1.inspect(logOutput, inspectOptions);
        return chalk_1.default.red(inspected);
    }
    else if (logOutput.level === 'WARN') {
        const inspected = util_1.inspect(logOutput, inspectOptions);
        return chalk_1.default.yellow(inspected);
    }
    else {
        return util_1.inspect(logOutput, Object.assign({}, inspectOptions, { colors: true // Add color, since output isn't in single color
         }));
    }
}
function prettyPrint(logOutput) {
    if ('PN_LOG_PRETTY' in process.env) {
        if (chalk_1.default.supportsColor.hasBasic) {
            return colorize(logOutput);
        }
        // color unsupported, return regular inspect
        return util_1.inspect(logOutput, inspectOptions);
    }
    else {
        // Regular JSON output
        try {
            // Try using native stringify - fast
            return JSON.stringify(logOutput, null, 2);
        }
        catch (_a) {
            // Use safe parser if it throws - slower, but handles circular references
            return safeStringify(logOutput, null, 2);
        }
    }
}
exports.prettyPrint = prettyPrint;
//# sourceMappingURL=prettyPrint.js.map